/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.fleet.machine.windows.MachineOverviewController;
import nl.cloudfarming.client.fleet.model.MachineProvider;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

@MultiViewElement.Registration(displayName = "#LBL_Vehicle_Data",
iconBase = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png",
mimeType = "application/x-agrosense-vehicle",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "Vehicle",
position = 1000)
@Messages({"LBL_Vehicle_Data=Data", "unknownPropertyValue=Unknown"})
public final class VehicleDataElement extends MachineOverviewController<VehicleOverviewPanel> implements MultiViewElement {

    private VehicleDataObject obj;
    private Vehicle vehicle;
    private JToolBar toolbar = new JToolBar();
    private ASBodyPanel overviewDecorator;
    private transient MultiViewElementCallback callback;
    private VehicleOverviewPanel vehicleOverviewPanel;

    public VehicleDataElement(Lookup lkp) {
        super(new VehicleOverviewPanel(lkp.lookup(Vehicle.class)) , lkp.lookup(Vehicle.class), Lookup.getDefault().lookupAll(VehicleDataService.class));
        obj = lkp.lookup(VehicleDataObject.class);
        vehicle = obj.getLookup().lookup(Vehicle.class);
        vehicle.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if (Vehicle.PROP_NAME.equals(evt.getPropertyName())) {
                    updateName();
                }
            }
        });
    }

    @Override
    public JComponent getVisualRepresentation() {
        if (overviewDecorator == null) {
            overviewDecorator = new ASBodyPanel(getOverviewPanel());
            overviewDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png", true));
        }
        return overviewDecorator;
    }

    @Override
    public MachineProvider getMachineProvider() {
        return Lookup.getDefault().lookup(VehicleManagerImpl.class);
    }

    @Override
    public Project getProject() {
        return EnterpriseIdProvider.ProjectFinder.find(vehicle.getURI());
    }

    @Override
    public void fieldsUpdated() {
        updateName();
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
        OpenCloseHandler.Event.triggerOpen(obj.getNodeDelegate());
    }

    @Override
    public void componentClosed() {
        OpenCloseHandler.Event.triggerClose(obj.getNodeDelegate());
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(vehicle.getName());
            tc.setDisplayName(vehicle.getName());
            tc.setName(vehicle.getName());
            tc.setToolTipText(vehicle.getName());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
