/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.io.IOException;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardAction;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardIterator;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

@NbBundle.Messages({"wizardTitle=New vehicle"})
public final class VehicleWizardAction extends MachineWizardAction {

    public VehicleWizardAction(Project project) {
        super(project, Bundle.wizardTitle());
    }

    @Override
    protected void createMachine(WizardDescriptor wiz) throws IOException {
        Vehicle vehicle = (Vehicle) wiz.getProperty(MachineWizardIterator.PROP_MACHINE);
        
        MachineDataService.Model model = (MachineDataService.Model) wiz.getProperty(MachineWizardIterator.PROP_MODEL);
       
        vehicle.setHorsepower((int) readProperty(Vehicle.PROP_HORSEPOWER, wiz, model));
        vehicle.setDisplacement((double) readProperty(Vehicle.PROP_DISPLACEMENT, wiz, model));
        vehicle.setFuelTankCapacity((int) readProperty(Vehicle.PROP_FUELTANKCAPACITY, wiz, model));

        addDynamicProperties(vehicle, wiz);

        Lookup.getDefault().lookup(VehicleManager.class).save(vehicle);
    }

    @Override
    public MachineWizardFactory getWizardFactory() {
        return new VehicleWizardFactory(getProject());
    }
}
