/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardIterator;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardPanel;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.Vehicle;
import org.openide.WizardDescriptor;

class VehicleWizardPanel2 extends MachineWizardPanel {

    private VehicleVisualPanel2 visualPanel;
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.vehicle.wizard");

    @Override
    protected VehicleVisualPanel2 getVisual() {
        if (visualPanel == null) {
            visualPanel = new VehicleVisualPanel2();
        }
        return visualPanel;
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
        setTitle(((Machine)wiz.getProperty(MachineWizardIterator.PROP_MACHINE)).getName());
        
        MachineDataService.Model model = (MachineDataService.Model) wiz.getProperty(MachineWizardIterator.PROP_MODEL);
        if(model != null) {
            getVisual().setHorsepowerValue(model.getProperty(Vehicle.PROP_HORSEPOWER));
            getVisual().setDisplacementValue(model.getProperty(Vehicle.PROP_DISPLACEMENT));
            getVisual().setFuelTankCapacityValue(model.getProperty(Vehicle.PROP_FUELTANKCAPACITY));
        } else {
            LOGGER.finest("No model present. Not entering any default values");
        }
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty(Vehicle.PROP_HORSEPOWER, getVisual().getHorsepowerValue());
        wiz.putProperty(Vehicle.PROP_DISPLACEMENT, getVisual().getDisplacementValue());
        wiz.putProperty(Vehicle.PROP_FUELTANKCAPACITY, getVisual().getFuelTankCapacityValue());
    }
}
